layouttools.set_line_breaks_by_line_duration_in_seconds_ge
==========================================================

.. autofunction:: abjad.tools.layouttools.set_line_breaks_by_line_duration_in_seconds_ge.set_line_breaks_by_line_duration_in_seconds_ge
